# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: SimulatorTables.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'SimulatorTables.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15SimulatorTables.proto\x12\x04rips\"?\n\x15SimulatorTableRequest\x12\x15\n\rwellpath_name\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\x05\"G\n\x1cSimulatorTableUnifiedRequest\x12\x16\n\x0ewellpath_names\x18\x01 \x03(\t\x12\x0f\n\x07\x63\x61se_id\x18\x02 \x01(\x05\"\xd2\x04\n\x15SimulatorCompdatEntry\x12\x11\n\twell_name\x18\x01 \x01(\t\x12\x0e\n\x06grid_i\x18\x02 \x01(\x05\x12\x0e\n\x06grid_j\x18\x03 \x01(\x05\x12\x0f\n\x07upper_k\x18\x04 \x01(\x05\x12\x0f\n\x07lower_k\x18\x05 \x01(\x05\x12\x16\n\x0eopen_shut_flag\x18\x06 \x01(\t\x12\x17\n\nsaturation\x18\x07 \x01(\x01H\x00\x88\x01\x01\x12\x1d\n\x10transmissibility\x18\x08 \x01(\x01H\x01\x88\x01\x01\x12\x15\n\x08\x64iameter\x18\t \x01(\x01H\x02\x88\x01\x01\x12\x0f\n\x02kh\x18\n \x01(\x01H\x03\x88\x01\x01\x12\x18\n\x0bskin_factor\x18\x0b \x01(\x01H\x04\x88\x01\x01\x12\x15\n\x08\x64_factor\x18\x0c \x01(\x01H\x05\x88\x01\x01\x12\x16\n\tdirection\x18\r \x01(\tH\x06\x88\x01\x01\x12\x15\n\x08start_md\x18\x0e \x01(\x01H\x07\x88\x01\x01\x12\x13\n\x06\x65nd_md\x18\x0f \x01(\x01H\x08\x88\x01\x01\x12\x14\n\x07\x63omment\x18\x10 \x01(\tH\t\x88\x01\x01\x12\x16\n\tgrid_name\x18\x11 \x01(\tH\n\x88\x01\x01\x12\x1e\n\x11\x63ompletion_number\x18\x12 \x01(\x05H\x0b\x88\x01\x01\x42\r\n\x0b_saturationB\x13\n\x11_transmissibilityB\x0b\n\t_diameterB\x05\n\x03_khB\x0e\n\x0c_skin_factorB\x0b\n\t_d_factorB\x0c\n\n_directionB\x0b\n\t_start_mdB\t\n\x07_end_mdB\n\n\x08_commentB\x0c\n\n_grid_nameB\x14\n\x12_completion_number\"\x80\x04\n\x16SimulatorWelspecsEntry\x12\x11\n\twell_name\x18\x01 \x01(\t\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x0e\n\x06grid_i\x18\x03 \x01(\x05\x12\x0e\n\x06grid_j\x18\x04 \x01(\x05\x12\x16\n\tbhp_depth\x18\x05 \x01(\x01H\x00\x88\x01\x01\x12\r\n\x05phase\x18\x06 \x01(\t\x12\x1c\n\x0f\x64rainage_radius\x18\x07 \x01(\x01H\x01\x88\x01\x01\x12\x1c\n\x0finflow_equation\x18\x08 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x61uto_shut_in\x18\t \x01(\tH\x03\x88\x01\x01\x12\x17\n\ncross_flow\x18\n \x01(\tH\x04\x88\x01\x01\x12\x14\n\x07pvt_num\x18\x0b \x01(\x05H\x05\x88\x01\x01\x12%\n\x18hydrostatic_density_calc\x18\x0c \x01(\tH\x06\x88\x01\x01\x12\x17\n\nfip_region\x18\r \x01(\x05H\x07\x88\x01\x01\x12\x16\n\tgrid_name\x18\x0e \x01(\tH\x08\x88\x01\x01\x42\x0c\n\n_bhp_depthB\x12\n\x10_drainage_radiusB\x12\n\x10_inflow_equationB\x0f\n\r_auto_shut_inB\r\n\x0b_cross_flowB\n\n\x08_pvt_numB\x1b\n\x19_hydrostatic_density_calcB\r\n\x0b_fip_regionB\x0c\n\n_grid_name\"\xfe\x01\n\x1bSimulatorWelsegsHeaderEntry\x12\x11\n\twell_name\x18\x01 \x01(\t\x12\x11\n\ttop_depth\x18\x02 \x01(\x01\x12\x12\n\ntop_length\x18\x03 \x01(\x01\x12\x1c\n\x0fwellbore_volume\x18\x04 \x01(\x01H\x00\x88\x01\x01\x12\x11\n\tinfo_type\x18\x05 \x01(\t\x12 \n\x13pressure_components\x18\x06 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nflow_model\x18\x07 \x01(\tH\x02\x88\x01\x01\x42\x12\n\x10_wellbore_volumeB\x16\n\x14_pressure_componentsB\r\n\x0b_flow_model\"\xf9\x01\n\x18SimulatorWelsegsRowEntry\x12\x11\n\tsegment_1\x18\x01 \x01(\x05\x12\x11\n\tsegment_2\x18\x02 \x01(\x05\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\x05\x12\x14\n\x0cjoin_segment\x18\x04 \x01(\x05\x12\x0e\n\x06length\x18\x05 \x01(\x01\x12\r\n\x05\x64\x65pth\x18\x06 \x01(\x01\x12\x15\n\x08\x64iameter\x18\x07 \x01(\x01H\x00\x88\x01\x01\x12\x16\n\troughness\x18\x08 \x01(\x01H\x01\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\t \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_diameterB\x0c\n\n_roughnessB\x0e\n\x0c_description\"w\n\x15SimulatorWelsegsEntry\x12\x31\n\x06header\x18\x01 \x01(\x0b\x32!.rips.SimulatorWelsegsHeaderEntry\x12+\n\x03row\x18\x02 \x03(\x0b\x32\x1e.rips.SimulatorWelsegsRowEntry\"\x9d\x01\n\x16SimulatorCompsegsEntry\x12\t\n\x01i\x18\x01 \x01(\x05\x12\t\n\x01j\x18\x02 \x01(\x05\x12\t\n\x01k\x18\x03 \x01(\x05\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\x05\x12\x16\n\x0e\x64istance_start\x18\x05 \x01(\x01\x12\x14\n\x0c\x64istance_end\x18\x06 \x01(\x01\x12\x16\n\tgrid_name\x18\x07 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_grid_name\"\xad\x02\n\x16SimulatorWsegvalvEntry\x12\x11\n\twell_name\x18\x01 \x01(\t\x12\x16\n\x0esegment_number\x18\x02 \x01(\x05\x12\n\n\x02\x63v\x18\x03 \x01(\x01\x12\x0c\n\x04\x61rea\x18\x04 \x01(\x01\x12\x19\n\x0c\x65xtra_length\x18\x05 \x01(\x01H\x00\x88\x01\x01\x12\x13\n\x06pipe_d\x18\x06 \x01(\x01H\x01\x88\x01\x01\x12\x16\n\troughness\x18\x07 \x01(\x01H\x02\x88\x01\x01\x12\x13\n\x06pipe_a\x18\x08 \x01(\x01H\x03\x88\x01\x01\x12\x13\n\x06status\x18\t \x01(\tH\x04\x88\x01\x01\x12\x12\n\x05max_a\x18\n \x01(\x01H\x05\x88\x01\x01\x42\x0f\n\r_extra_lengthB\t\n\x07_pipe_dB\x0c\n\n_roughnessB\t\n\x07_pipe_aB\t\n\x07_statusB\x08\n\x06_max_a\"\x86\x07\n\x16SimulatorWsegaicdEntry\x12\x11\n\twell_name\x18\x01 \x01(\t\x12\x11\n\tsegment_1\x18\x02 \x01(\x05\x12\x11\n\tsegment_2\x18\x03 \x01(\x05\x12\x10\n\x08strength\x18\x04 \x01(\x01\x12\x13\n\x06length\x18\x05 \x01(\x01H\x00\x88\x01\x01\x12\x19\n\x0c\x64\x65nsity_cali\x18\x06 \x01(\x01H\x01\x88\x01\x01\x12\x1b\n\x0eviscosity_cali\x18\x07 \x01(\x01H\x02\x88\x01\x01\x12\x1b\n\x0e\x63ritical_value\x18\x08 \x01(\x01H\x03\x88\x01\x01\x12\x18\n\x0bwidth_trans\x18\t \x01(\x01H\x04\x88\x01\x01\x12\x1b\n\x0emax_visc_ratio\x18\n \x01(\x01H\x05\x88\x01\x01\x12\"\n\x15method_scaling_factor\x18\x0b \x01(\x05H\x06\x88\x01\x01\x12\x14\n\x0cmax_abs_rate\x18\x0c \x01(\x01\x12\x1a\n\x12\x66low_rate_exponent\x18\r \x01(\x01\x12\x15\n\rvisc_exponent\x18\x0e \x01(\x01\x12\x13\n\x06status\x18\x0f \x01(\tH\x07\x88\x01\x01\x12\x1e\n\x11oil_flow_fraction\x18\x10 \x01(\x01H\x08\x88\x01\x01\x12 \n\x13water_flow_fraction\x18\x11 \x01(\x01H\t\x88\x01\x01\x12\x1e\n\x11gas_flow_fraction\x18\x12 \x01(\x01H\n\x88\x01\x01\x12\x1e\n\x11oil_visc_fraction\x18\x13 \x01(\x01H\x0b\x88\x01\x01\x12 \n\x13water_visc_fraction\x18\x14 \x01(\x01H\x0c\x88\x01\x01\x12\x1e\n\x11gas_visc_fraction\x18\x15 \x01(\x01H\r\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x16 \x01(\tH\x0e\x88\x01\x01\x42\t\n\x07_lengthB\x0f\n\r_density_caliB\x11\n\x0f_viscosity_caliB\x11\n\x0f_critical_valueB\x0e\n\x0c_width_transB\x11\n\x0f_max_visc_ratioB\x18\n\x16_method_scaling_factorB\t\n\x07_statusB\x14\n\x12_oil_flow_fractionB\x16\n\x14_water_flow_fractionB\x14\n\x12_gas_flow_fractionB\x14\n\x12_oil_visc_fractionB\x16\n\x14_water_visc_fractionB\x14\n\x12_gas_visc_fractionB\x0e\n\x0c_description\"\x81\x01\n\x15SimulatorWpimultEntry\x12\x11\n\twell_name\x18\x01 \x01(\t\x12\x0e\n\x06pimult\x18\x02 \x01(\x01\x12\t\n\x01i\x18\x03 \x01(\x05\x12\t\n\x01j\x18\x04 \x01(\x05\x12\t\n\x01k\x18\x05 \x01(\x05\x12\x16\n\tgrid_name\x18\x06 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_grid_name\"\xde\x02\n\x12SimulatorTableData\x12,\n\x07\x63ompdat\x18\x01 \x03(\x0b\x32\x1b.rips.SimulatorCompdatEntry\x12.\n\x08welspecs\x18\x02 \x03(\x0b\x32\x1c.rips.SimulatorWelspecsEntry\x12,\n\x07welsegs\x18\x03 \x03(\x0b\x32\x1b.rips.SimulatorWelsegsEntry\x12.\n\x08\x63ompsegs\x18\x04 \x03(\x0b\x32\x1c.rips.SimulatorCompsegsEntry\x12.\n\x08wsegvalv\x18\x05 \x03(\x0b\x32\x1c.rips.SimulatorWsegvalvEntry\x12.\n\x08wsegaicd\x18\x06 \x03(\x0b\x32\x1c.rips.SimulatorWsegaicdEntry\x12,\n\x07wpimult\x18\x07 \x03(\x0b\x32\x1b.rips.SimulatorWpimultEntry2\xb4\x01\n\x08WellPath\x12L\n\x11GetCompletionData\x12\x1b.rips.SimulatorTableRequest\x1a\x18.rips.SimulatorTableData\"\x00\x12Z\n\x18GetCompletionDataUnified\x12\".rips.SimulatorTableUnifiedRequest\x1a\x18.rips.SimulatorTableData\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'SimulatorTables_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SIMULATORTABLEREQUEST']._serialized_start=31
  _globals['_SIMULATORTABLEREQUEST']._serialized_end=94
  _globals['_SIMULATORTABLEUNIFIEDREQUEST']._serialized_start=96
  _globals['_SIMULATORTABLEUNIFIEDREQUEST']._serialized_end=167
  _globals['_SIMULATORCOMPDATENTRY']._serialized_start=170
  _globals['_SIMULATORCOMPDATENTRY']._serialized_end=764
  _globals['_SIMULATORWELSPECSENTRY']._serialized_start=767
  _globals['_SIMULATORWELSPECSENTRY']._serialized_end=1279
  _globals['_SIMULATORWELSEGSHEADERENTRY']._serialized_start=1282
  _globals['_SIMULATORWELSEGSHEADERENTRY']._serialized_end=1536
  _globals['_SIMULATORWELSEGSROWENTRY']._serialized_start=1539
  _globals['_SIMULATORWELSEGSROWENTRY']._serialized_end=1788
  _globals['_SIMULATORWELSEGSENTRY']._serialized_start=1790
  _globals['_SIMULATORWELSEGSENTRY']._serialized_end=1909
  _globals['_SIMULATORCOMPSEGSENTRY']._serialized_start=1912
  _globals['_SIMULATORCOMPSEGSENTRY']._serialized_end=2069
  _globals['_SIMULATORWSEGVALVENTRY']._serialized_start=2072
  _globals['_SIMULATORWSEGVALVENTRY']._serialized_end=2373
  _globals['_SIMULATORWSEGAICDENTRY']._serialized_start=2376
  _globals['_SIMULATORWSEGAICDENTRY']._serialized_end=3278
  _globals['_SIMULATORWPIMULTENTRY']._serialized_start=3281
  _globals['_SIMULATORWPIMULTENTRY']._serialized_end=3410
  _globals['_SIMULATORTABLEDATA']._serialized_start=3413
  _globals['_SIMULATORTABLEDATA']._serialized_end=3763
  _globals['_WELLPATH']._serialized_start=3766
  _globals['_WELLPATH']._serialized_end=3946
# @@protoc_insertion_point(module_scope)
